==> jclouds-2.4.0-source-release.tar.gz: jclouds-2.4.0/apis/ec2/src/main/java/org/jclouds/ec2/compute/functions/ImagesToRegionAndIdMap.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jclouds.ec2.compute.functions;

import static com.google.common.base.Preconditions.checkState;
import static com.google.common.collect.Maps.uniqueIndex;

import java.util.Map;

import javax.inject.Singleton;

import org.jclouds.compute.domain.Image;
import org.jclouds.ec2.compute.domain.RegionAndName;

import com.google.common.base.Function;
import com.google.common.base.Preconditions;

@Singleton
public class ImagesToRegionAndIdMap implements Function<Iterable<? extends Image>, Map<RegionAndName, ? extends Image>> {

   public static Map<RegionAndName, ? extends Image> imagesToMap(Iterable<? extends Image> input) {
      return new ImagesToRegionAndIdMap().apply(input);
   }

   @Override
   public Map<RegionAndName, ? extends Image> apply(Iterable<? extends Image> input) {
      return uniqueIndex(input, new Function<Image, RegionAndName>() {

         @Override
         public RegionAndName apply(Image from) {
            checkState(from.getLocation() != null,
                     "in ec2, image locations cannot be null; typically, they are Region-scoped");
            String[] segments = from.getId().split("/");
            Preconditions.checkArgument(segments.length == 2, "Wrong form for AWS image ID: " + from);
            return new RegionAndName(segments[0], segments[1]);
         }

      });
   }

}

==> jclouds-2.7.0-source-release.tar.gz: jclouds-2.7.0/apis/ec2/src/main/java/org/jclouds/ec2/compute/functions/ImagesToRegionAndIdMap.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jclouds.ec2.compute.functions;

import static com.google.common.base.Preconditions.checkState;
import static com.google.common.collect.Maps.uniqueIndex;

import java.util.Map;

import jakarta.inject.Singleton;

import org.jclouds.compute.domain.Image;
import org.jclouds.ec2.compute.domain.RegionAndName;

import com.google.common.base.Function;
import com.google.common.base.Preconditions;

@Singleton
public class ImagesToRegionAndIdMap implements Function<Iterable<? extends Image>, Map<RegionAndName, ? extends Image>> {

   public static Map<RegionAndName, ? extends Image> imagesToMap(Iterable<? extends Image> input) {
      return new ImagesToRegionAndIdMap().apply(input);
   }

   @Override
   public Map<RegionAndName, ? extends Image> apply(Iterable<? extends Image> input) {
      return uniqueIndex(input, new Function<Image, RegionAndName>() {

         @Override
         public RegionAndName apply(Image from) {
            checkState(from.getLocation() != null,
                     "in ec2, image locations cannot be null; typically, they are Region-scoped");
            String[] segments = from.getId().split("/");
            Preconditions.checkArgument(segments.length == 2, "Wrong form for AWS image ID: " + from);
            return new RegionAndName(segments[0], segments[1]);
         }

      });
   }

}
